@@ -1,7 +1,29 @@
 from pathlib import PurePath, Path
 from zipfile import ZipFile, is_zipfile, BadZipFile
 from zlib import decompressobj, MAX_WBITS, error as ZLIB_error
-from aiofile import async_open
+
+missed_modules = 0
+
+try:
+    from aiofile import async_open
+except ModuleNotFoundError as err:
+    missed_modules += 1
+
+try:
+    from aiofiles import open as async_open
+except ModuleNotFoundError as err:
+    missed_modules += 1
+except ImportError as err:
+    missed_modules += 1
+
+if missed_modules == 2:
+    print("""Not aiofile nor aiofiles is present! Going to crash..
+        please do:
+            pip install aiofile
+        or
+            pip install aiofiles
+        to make the code working, Thanks!""")
+
 
 DEFAULT_READ_BUFFER_SIZE = 64 * 1024
 
